@@ -21,7 +21,7 @@ Still incomplete!
 
 =head1 NAME
 
-Mojolicious::Plugin::RoutesAuthDBI::Admin - is a Mojolicious::Controller for manage admin operations on DBI tables: controllers, actions, routes, roles, users.
+Mojolicious::Plugin::RoutesAuthDBI::Admin - is a Mojolicious::Controller for manage admin operations on DBI tables: namespaces, controllers, actions, routes, roles, users.
 
 =head1 DB DESIGN DIAGRAM
 
@@ -76,6 +76,12 @@ Both above options determining the module controller for web actions on tables r
 
 =back
 
+=head1 SEE ALSO
+
+L<Mojolicious::Plugin::RoutesAuthDBI>
+
+L<Mojolicious::Plugin::RoutesAuthDBI::Sth>
+
 =head1 AUTHOR
 
 Михаил Че (Mikhail Che), C<< <mche [on] cpan.org> >>
